# encoding: utf-8

class Honor
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::MultiParameterAttributes
  
  # scope :available_for_lang, ->(locale){ where("available_for_#{locale}".to_sym => true) }
  
  LANGUAGE_TYPES = [ "English", "Chinese" ]


  
  has_and_belongs_to_many :tags, :class_name => "PersonalHonorTag"
  
  belongs_to :honor_category
  
  field :year
  field :award_name
  field :awarding_unit
  field :language
  field :keywords
  field :url
  field :note
  field :create_user_id
  field :update_user_id
  
  # field :is_top, :type => Boolean, :default => false 
  # field :is_hot, :type => Boolean, :default => false 
  # field :is_hidden, :type => Boolean, :default => false 
  
  # before_save :update_avliable_language, :clean_checkboxs

  validates_presence_of :award_name

  before_validation :add_http
  
  validates :url, :format => /^(http|https):\/\/[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(([0-9]{1,5})?\/.*)?$/ix, :unless => Proc.new{self.url.blank?}

  def self.search( category_id = nil )
  
	if category_id.to_s.size > 0
	
	  find(:all, :conditions => {honor_category_id: category_id}).desc( :is_top, :title )

	else
	  
	  find(:all).desc( :is_top, :title)
	  
	end
	
  end


  def self.widget_datas
  
	where( :is_hidden => false ).desc(:is_top, :created_at)

  end

  def is_top?
    self.is_top
  end 

  def sorted_tags
    tags.order_by(I18n.locale, :asc)
  end
  
  def update_avliable_language
    VALID_LOCALES.each  do |locale|
      if (title_translations[locale].blank? rescue true)
        self["available_for_#{locale}".to_sym] = false 
      else
        self["available_for_#{locale}".to_sym] = true
      end
    end
  end

  protected

  def add_http
    unless self.url.blank? || self.url[/^http:\/\//] || self.url[/^https:\/\//]
      self.url = 'http://' + self.url
    end
  end

  def clean_checkboxs
    self.tag_ids.delete('')
  end
  
end