# encoding: utf-8

class WritingJournal
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::MultiParameterAttributes
  
  # scope :available_for_lang, ->(locale){ where("available_for_#{locale}".to_sym => true) }
  
  LANGUAGE_TYPES = [ "English", "Chinese" ]


  field :paper_title, localize: true
  field :journal_title, localize: true
  field :authors, localize: true
  
  has_and_belongs_to_many :tags, :class_name => "PersonalJournalTag"
  
  has_and_belongs_to_many :journal_author_types
  has_and_belongs_to_many :journal_level_types
  
  belongs_to :journal_paper_type
  
  field :year
  field :language
  field :isbn
  field :vol_no
  field :issue_no
  field :form_to
  field :total_pages
  field :keywords
  field :abstract
  field :publication_date, :type => Date
  field :url
  field :note
  field :create_user_id
  field :update_user_id
  
  # field :is_top, :type => Boolean, :default => false 
  # field :is_hot, :type => Boolean, :default => false 
  # field :is_hidden, :type => Boolean, :default => false 
  
  has_many :writing_journal_files, :autosave => true, :dependent => :destroy
  
  accepts_nested_attributes_for :writing_journal_files, :allow_destroy => true
  
  # before_save :update_avliable_language, :clean_checkboxs

  validates :paper_title, :at_least_one => true

  before_validation :add_http
  
  after_save :save_writing_journal_files
  
  validates :url, :format => /^(http|https):\/\/[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(([0-9]{1,5})?\/.*)?$/ix, :unless => Proc.new{self.url.blank?}

  def self.search( category_id = nil )
  
	if category_id.to_s.size > 0
	
	  find(:all, :conditions => {writing_journal_category_id: category_id}).desc( :is_top, :title )

	else
	  
	  find(:all).desc( :is_top, :title)
	  
	end
	
  end


  def self.widget_datas
  
	where( :is_hidden => false ).desc(:is_top, :created_at)

  end

  def is_top?
    self.is_top
  end 

  def sorted_tags
    tags.order_by(I18n.locale, :asc)
  end
  
  def update_avliable_language
    VALID_LOCALES.each  do |locale|
      if (title_translations[locale].blank? rescue true)
        self["available_for_#{locale}".to_sym] = false 
      else
        self["available_for_#{locale}".to_sym] = true
      end
    end
  end
  
  def save_writing_journal_files
	self.writing_journal_files.each do |t|
	  if t.should_destroy
		t.destroy
	  end
    end
  end
  
  def create_link
    
	title = ["\"#{self.paper_title}\""]
	title << self.journal_title
		title.join(', ')
	title << ( !self.journal_level_types.blank? ? "(#{self.journal_level_types.collect{|x| x.title}.join(', ')})" : nil)
	title.join(', ')
  end

  protected

  def add_http
    unless self.url.blank? || self.url[/^http:\/\//] || self.url[/^https:\/\//]
      self.url = 'http://' + self.url
    end
  end

  def clean_checkboxs
    self.tag_ids.delete('')
    self.journal_author_type_ids.delete('')
    self.journal_level_type_ids.delete('')
  end
  
end