# encoding: utf-8

class WebLink
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::MultiParameterAttributes
  
  scope :available_for_lang, ->(locale){ where("available_for_#{locale}".to_sym => true) }

  field :title, localize: true
  field :context, localize: true
  
  has_and_belongs_to_many :tags, :class_name => "WebResourceTag"
  
  field :url
  field :create_user_id
  field :update_user_id
  
  field :is_top, :type => Boolean, :default => false 
  field :is_hot, :type => Boolean, :default => false 
  field :is_hidden, :type => Boolean, :default => false 
  
  belongs_to :web_link_category
  
  before_save :update_avliable_language, :clean_tags

  validates :title, :at_least_one => true

  before_validation :add_http
  validates :url, :presence => true, :format => /^(http|https):\/\/[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(([0-9]{1,5})?\/.*)?$/ix

  def self.search( category_id = nil )
  
	if category_id.to_s.size > 0
	
	  find(:all, :conditions => {web_link_category_id: category_id}).desc( :is_top, :title )

	else
	  
	  find(:all).desc( :is_top, :title)
	  
	end
	
  end


  def self.widget_datas
  
	where( :is_hidden => false ).desc(:is_top, :created_at)

  end

  def is_top?
    self.is_top
  end 

  def sorted_tags
    tags.order_by(I18n.locale, :asc)
  end
  
  def update_avliable_language
    VALID_LOCALES.each  do |locale|
      if (title_translations[locale].blank? rescue true)
        self["available_for_#{locale}".to_sym] = false 
      else
        self["available_for_#{locale}".to_sym] = true
      end
    end
  end

  protected

  def add_http
    unless self.url[/^http:\/\//] || self.url[/^https:\/\//]
      self.url = 'http://' + self.url
    end
  end

  def clean_tags
    self.tag_ids.delete('')
  end
  
end